@@ -60,13 +60,6 @@ update_packages ()
 }
 #endif
 
-void
-update_light_status (int state)
-{
-	if ((state >= 0) && (state <= 1))
-		turn_light (state);
-}
-
 void
 update_screen_brightness (int br)
 {
@@ -422,11 +415,6 @@ suidloop (int write, int read)
 					fscanf (in, "%d", &numarg);
 					update_screen_rotation (numarg);
 				}
-				else if (strcmp (cmd, "SCRL") == 0)  // chnage frontlight state
-				{
-					fscanf (in, "%d", &numarg);
-					update_light_status (numarg);
-				}
 				else if (strcmp (cmd, "CRHD") == 0)  // create a users home directory
 				{
 					fscanf (in, "%100s", arg1);	// directory
